'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var esbuild = require('esbuild');
var path2 = require('path');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var path2__default = /*#__PURE__*/_interopDefaultLegacy(path2);

const getExt = (str) => {
  const basename = path2__default['default'].basename(str);
  const firstDot = basename.indexOf(".");
  const lastDot = basename.lastIndexOf(".");
  const extname2 = path2__default['default'].extname(basename).replace(/(\.[a-z0-9]+).*/i, "$1");
  if (firstDot === lastDot)
    return extname2;
  return basename.slice(firstDot, lastDot) + extname2;
};
const getOptions = (config) => {
  let options = {};
  for (let i = 0; i < config.transform.length; i++) {
    options = config.transform[i][2];
  }
  return options;
};
function process(content, filename, config) {
  const options = getOptions(config);
  const ext = getExt(filename);
  const loader = (options == null ? void 0 : options.loaders) && (options == null ? void 0 : options.loaders[ext]) ? options.loaders[ext] : path2.extname(filename).slice(1);
  const sourcemaps = (options == null ? void 0 : options.sourcemap) ? {sourcemap: true, sourcefile: filename} : {};
  const result = esbuild.transformSync(content, {
    loader,
    format: (options == null ? void 0 : options.format) || "cjs",
    target: (options == null ? void 0 : options.target) || "es2018",
    ...(options == null ? void 0 : options.jsxFactory) ? {jsxFactory: options.jsxFactory} : {},
    ...(options == null ? void 0 : options.jsxFragment) ? {jsxFragment: options.jsxFragment} : {},
    ...sourcemaps
  });
  return {
    code: result.code,
    map: (result == null ? void 0 : result.map) ? {
      ...JSON.parse(result.map),
      sourcesContent: null
    } : ""
  };
}

exports.process = process;
